functor BuildAstLexFun(structure Tokens: BuildAst_TOKENS)  = struct

    structure yyInput : sig

        type stream
	val mkStream : (int -> string) -> stream
	val fromStream : TextIO.StreamIO.instream -> stream
	val getc : stream -> (Char.char * stream) option
	val getpos : stream -> int
	val getlineNo : stream -> int
	val subtract : stream * stream -> string
	val eof : stream -> bool
	val lastWasNL : stream -> bool

      end = struct

        structure TIO = TextIO
        structure TSIO = TIO.StreamIO
	structure TPIO = TextPrimIO

        datatype stream = Stream of {
            strm : TSIO.instream,
	    id : int,  (* track which streams originated 
			* from the same stream *)
	    pos : int,
	    lineNo : int,
	    lastWasNL : bool
          }

	local
	  val next = ref 0
	in
	fun nextId() = !next before (next := !next + 1)
	end

	val initPos = 2 (* ml-lex bug compatibility *)

	fun mkStream inputN = let
              val strm = TSIO.mkInstream 
			   (TPIO.RD {
			        name = "lexgen",
				chunkSize = 4096,
				readVec = SOME inputN,
				readArr = NONE,
				readVecNB = NONE,
				readArrNB = NONE,
				block = NONE,
				canInput = NONE,
				avail = (fn () => NONE),
				getPos = NONE,
				setPos = NONE,
				endPos = NONE,
				verifyPos = NONE,
				close = (fn () => ()),
				ioDesc = NONE
			      }, "")
	      in 
		Stream {strm = strm, id = nextId(), pos = initPos, lineNo = 1,
			lastWasNL = true}
	      end

	fun fromStream strm = Stream {
		strm = strm, id = nextId(), pos = initPos, lineNo = 1, lastWasNL = true
	      }

	fun getc (Stream {strm, pos, id, lineNo, ...}) = (case TSIO.input1 strm
              of NONE => NONE
	       | SOME (c, strm') => 
		   SOME (c, Stream {
			        strm = strm', 
				pos = pos+1, 
				id = id,
				lineNo = lineNo + 
					 (if c = #"\n" then 1 else 0),
				lastWasNL = (c = #"\n")
			      })
	     (* end case*))

	fun getpos (Stream {pos, ...}) = pos

	fun getlineNo (Stream {lineNo, ...}) = lineNo

	fun subtract (new, old) = let
	      val Stream {strm = strm, pos = oldPos, id = oldId, ...} = old
	      val Stream {pos = newPos, id = newId, ...} = new
              val (diff, _) = if newId = oldId andalso newPos >= oldPos
			      then TSIO.inputN (strm, newPos - oldPos)
			      else raise Fail 
				"BUG: yyInput: attempted to subtract incompatible streams"
	      in 
		diff 
	      end

	fun eof (Stream {strm, ...}) = TSIO.endOfStream strm

	fun lastWasNL (Stream {lastWasNL, ...}) = lastWasNL

      end

    datatype yystart_state = 
INITIAL
    structure UserDeclarations = 
      struct

structure T = Tokens;     

(* Types *)
type pos = int;
type svalue = Tokens.svalue;
type ('a,'b) token = ('a,'b) Tokens.token;
type lexresult= (svalue,pos) token;

type lexarg = string;
type arg = lexarg;

(* Error handling info for yacc *)
val lin = ref 1;
val col = ref 0 ;
val eolpos = ref 0 ;

(* End of file management *)
val eof = fn fileName => T.EOF (!lin,!col) ;
fun len s = List.length(explode s);
val atoi = fn (a,r) => ord(a)-ord(#"0")+10*r;
val atof = fn (a,r) => real(ord(a)-ord(#"0"))+r/10.0;

fun realize l =  let
                        fun split [] l = (l,[])
                           |split (x::xs) l = if(x = #".") then (l,xs)
                                              else (split xs (x::l))
                        val (l1,l2) = split l []
                        val num = foldr atoi 0 l1
                        val frac = foldr atof 0.0 l2
                in
                real(num)+frac/10.0
                end;

fun toReal l = if((hd l)= #"~") then (~(realize (tl l))) else (realize l);
fun toInt l = if ((hd l)= #"~") then (~(toInt (tl l))) else (foldl atoi 0 l);
fun chop s = implode(rev(tl(rev(tl(explode s)))));

open DataTypes;


      end

    datatype yymatch 
      = yyNO_MATCH
      | yyMATCH of yyInput.stream * action * yymatch
    withtype action = yyInput.stream * yymatch -> UserDeclarations.lexresult

    local

    val yytable = 
#[
]

    fun mk yyins = let
        (* current start state *)
        val yyss = ref INITIAL
	fun YYBEGIN ss = (yyss := ss)
	(* current input stream *)
        val yystrm = ref yyins
	(* get one char of input *)
	val yygetc = yyInput.getc
	(* create yytext *)
	fun yymktext(strm) = yyInput.subtract (strm, !yystrm)
        open UserDeclarations
        fun lex 
(yyarg as (fileName:string)) () = let 
     fun continue() = let
            val yylastwasn = yyInput.lastWasNL (!yystrm)
            fun yystuck (yyNO_MATCH) = raise Fail "stuck state"
	      | yystuck (yyMATCH (strm, action, old)) = 
		  action (strm, old)
	    val yypos = yyInput.getpos (!yystrm)
	    val yygetlineNo = yyInput.getlineNo
	    fun yyactsToMatches (strm, [],	  oldMatches) = oldMatches
	      | yyactsToMatches (strm, act::acts, oldMatches) = 
		  yyMATCH (strm, act, yyactsToMatches (strm, acts, oldMatches))
	    fun yygo actTable = 
		(fn (~1, _, oldMatches) => yystuck oldMatches
		  | (curState, strm, oldMatches) => let
		      val (transitions, finals') = Vector.sub (yytable, curState)
		      val finals = map (fn i => Vector.sub (actTable, i)) finals'
		      fun tryfinal() = 
		            yystuck (yyactsToMatches (strm, finals, oldMatches))
		      fun find (c, []) = NONE
			| find (c, (c1, c2, s)::ts) = 
		            if c1 <= c andalso c <= c2 then SOME s
			    else find (c, ts)
		      in case yygetc strm
			  of SOME(c, strm') => 
			       (case find (c, transitions)
				 of NONE => tryfinal()
				  | SOME n => 
				      yygo actTable
					(n, strm', 
					 yyactsToMatches (strm, finals, oldMatches)))
			   | NONE => tryfinal()
		      end)
	    in 
let
fun yyAction0 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ((col := !col + (len yytext));continue ())
      end
fun yyAction1 (strm, lastMatch : yymatch) = (yystrm := strm;
      ((lin := !lin + 1);(col := 0);continue()))
fun yyAction2 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ((col := !col + (len yytext));T.NEW(!lin,!col))
      end
fun yyAction3 (strm, lastMatch : yymatch) = (yystrm := strm;
      ((col := !col + 1);T.LPAREN(!lin,!col)))
fun yyAction4 (strm, lastMatch : yymatch) = (yystrm := strm;
      ((col := !col + 1);T.RPAREN(!lin,!col)))
fun yyAction5 (strm, lastMatch : yymatch) = (yystrm := strm;
      ((col := !col + 1);T.LBRACE(!lin,!col)))
fun yyAction6 (strm, lastMatch : yymatch) = (yystrm := strm;
      ((col := !col + 1);T.RBRACE(!lin,!col)))
fun yyAction7 (strm, lastMatch : yymatch) = (yystrm := strm;
      ((col := !col + 1);T.ASMT(!lin,!col)))
fun yyAction8 (strm, lastMatch : yymatch) = (yystrm := strm;
      ((col := !col + 1);T.COMMA(!lin,!col)))
fun yyAction9 (strm, lastMatch : yymatch) = (yystrm := strm;
      ((col := !col + 7);T.PROGRAM(!lin,!col)))
fun yyAction10 (strm, lastMatch : yymatch) = (yystrm := strm;
      ((col := !col + 9);T.PROC(!lin,!col)))
fun yyAction11 (strm, lastMatch : yymatch) = (yystrm := strm;
      ((col := !col + 6);T.ASSIGN(!lin,!col)))
fun yyAction12 (strm, lastMatch : yymatch) = (yystrm := strm;
      ((col := !col + 3);T.VAR(!lin,!col)))
fun yyAction13 (strm, lastMatch : yymatch) = (yystrm := strm;
      ((col := !col + 6);T.PARAM(!lin,!col)))
fun yyAction14 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm;
        ((col := !col + (len yytext));T.IDENTIFIER(yytext,!lin,!col))
      end
fun yyAction15 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm;
        ((col := !col + (len yytext));T.REAL((toReal (explode yytext)),!lin,!col))
      end
fun yyAction16 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm;
        ((col := !col + (len yytext));T.NUM((toInt (explode yytext)),!lin,!col))
      end
fun yyAction17 (strm, lastMatch : yymatch) = (yystrm := strm; (continue ()))
fun yyQ20 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction15(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"1"
              then yyQ20(strm', yyMATCH(strm, yyAction15, yyNO_MATCH))
            else if inp < #"1"
              then if inp = #"0"
                  then yyQ21(strm', yyMATCH(strm, yyAction15, yyNO_MATCH))
                  else yyAction15(strm, yyNO_MATCH)
            else if inp <= #"9"
              then yyQ20(strm', yyMATCH(strm, yyAction15, yyNO_MATCH))
              else yyAction15(strm, yyNO_MATCH)
      (* end case *))
and yyQ21 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yystuck(lastMatch)
        | SOME(inp, strm') =>
            if inp = #"1"
              then yyQ20(strm', lastMatch)
            else if inp < #"1"
              then if inp = #"0"
                  then yyQ21(strm', lastMatch)
                  else yystuck(lastMatch)
            else if inp <= #"9"
              then yyQ20(strm', lastMatch)
              else yystuck(lastMatch)
      (* end case *))
fun yyQ19 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yystuck(lastMatch)
        | SOME(inp, strm') =>
            if inp = #"0"
              then yyQ20(strm', lastMatch)
            else if inp < #"0"
              then yystuck(lastMatch)
            else if inp <= #"9"
              then yyQ20(strm', lastMatch)
              else yystuck(lastMatch)
      (* end case *))
fun yyQ18 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction16(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"/"
              then yyAction16(strm, yyNO_MATCH)
            else if inp < #"/"
              then if inp = #"."
                  then yyQ19(strm', yyMATCH(strm, yyAction16, yyNO_MATCH))
                  else yyAction16(strm, yyNO_MATCH)
            else if inp <= #"9"
              then yyQ18(strm', yyMATCH(strm, yyAction16, yyNO_MATCH))
              else yyAction16(strm, yyNO_MATCH)
      (* end case *))
fun yyQ17 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction17(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"1"
              then yyQ18(strm', yyMATCH(strm, yyAction17, yyNO_MATCH))
            else if inp < #"1"
              then yyAction17(strm, yyNO_MATCH)
            else if inp <= #"9"
              then yyQ18(strm', yyMATCH(strm, yyAction17, yyNO_MATCH))
              else yyAction17(strm, yyNO_MATCH)
      (* end case *))
fun yyQ16 (strm, lastMatch : yymatch) = yyAction6(strm, yyNO_MATCH)
fun yyQ15 (strm, lastMatch : yymatch) = yyAction5(strm, yyNO_MATCH)
fun yyQ22 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction14(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"A"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"A"
              then if inp = #"("
                  then yyAction14(strm, yyNO_MATCH)
                else if inp < #"("
                  then if inp = #"'"
                      then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                      else yyAction14(strm, yyNO_MATCH)
                else if inp = #"0"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp < #"0"
                  then yyAction14(strm, yyNO_MATCH)
                else if inp <= #"9"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyAction14(strm, yyNO_MATCH)
            else if inp = #"`"
              then yyAction14(strm, yyNO_MATCH)
            else if inp < #"`"
              then if inp = #"["
                  then yyAction14(strm, yyNO_MATCH)
                else if inp < #"["
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp = #"_"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyAction14(strm, yyNO_MATCH)
            else if inp <= #"z"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
              else yyAction14(strm, yyNO_MATCH)
      (* end case *))
fun yyQ24 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction12(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"A"
              then yyQ22(strm', yyMATCH(strm, yyAction12, yyNO_MATCH))
            else if inp < #"A"
              then if inp = #"("
                  then yyAction12(strm, yyNO_MATCH)
                else if inp < #"("
                  then if inp = #"'"
                      then yyQ22(strm', yyMATCH(strm, yyAction12, yyNO_MATCH))
                      else yyAction12(strm, yyNO_MATCH)
                else if inp = #"0"
                  then yyQ22(strm', yyMATCH(strm, yyAction12, yyNO_MATCH))
                else if inp < #"0"
                  then yyAction12(strm, yyNO_MATCH)
                else if inp <= #"9"
                  then yyQ22(strm', yyMATCH(strm, yyAction12, yyNO_MATCH))
                  else yyAction12(strm, yyNO_MATCH)
            else if inp = #"`"
              then yyAction12(strm, yyNO_MATCH)
            else if inp < #"`"
              then if inp = #"["
                  then yyAction12(strm, yyNO_MATCH)
                else if inp < #"["
                  then yyQ22(strm', yyMATCH(strm, yyAction12, yyNO_MATCH))
                else if inp = #"_"
                  then yyQ22(strm', yyMATCH(strm, yyAction12, yyNO_MATCH))
                  else yyAction12(strm, yyNO_MATCH)
            else if inp <= #"z"
              then yyQ22(strm', yyMATCH(strm, yyAction12, yyNO_MATCH))
              else yyAction12(strm, yyNO_MATCH)
      (* end case *))
fun yyQ23 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction14(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"["
              then yyAction14(strm, yyNO_MATCH)
            else if inp < #"["
              then if inp = #"0"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp < #"0"
                  then if inp = #"'"
                      then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                      else yyAction14(strm, yyNO_MATCH)
                else if inp = #":"
                  then yyAction14(strm, yyNO_MATCH)
                else if inp < #":"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp <= #"@"
                  then yyAction14(strm, yyNO_MATCH)
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp = #"a"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"a"
              then if inp = #"_"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyAction14(strm, yyNO_MATCH)
            else if inp = #"s"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"s"
              then if inp = #"r"
                  then yyQ24(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp <= #"z"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
              else yyAction14(strm, yyNO_MATCH)
      (* end case *))
fun yyQ14 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction14(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"["
              then yyAction14(strm, yyNO_MATCH)
            else if inp < #"["
              then if inp = #"0"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp < #"0"
                  then if inp = #"'"
                      then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                      else yyAction14(strm, yyNO_MATCH)
                else if inp = #":"
                  then yyAction14(strm, yyNO_MATCH)
                else if inp < #":"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp <= #"@"
                  then yyAction14(strm, yyNO_MATCH)
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp = #"a"
              then yyQ23(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"a"
              then if inp = #"_"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyAction14(strm, yyNO_MATCH)
            else if inp <= #"z"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
              else yyAction14(strm, yyNO_MATCH)
      (* end case *))
fun yyQ32 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction9(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"A"
              then yyQ22(strm', yyMATCH(strm, yyAction9, yyNO_MATCH))
            else if inp < #"A"
              then if inp = #"("
                  then yyAction9(strm, yyNO_MATCH)
                else if inp < #"("
                  then if inp = #"'"
                      then yyQ22(strm', yyMATCH(strm, yyAction9, yyNO_MATCH))
                      else yyAction9(strm, yyNO_MATCH)
                else if inp = #"0"
                  then yyQ22(strm', yyMATCH(strm, yyAction9, yyNO_MATCH))
                else if inp < #"0"
                  then yyAction9(strm, yyNO_MATCH)
                else if inp <= #"9"
                  then yyQ22(strm', yyMATCH(strm, yyAction9, yyNO_MATCH))
                  else yyAction9(strm, yyNO_MATCH)
            else if inp = #"`"
              then yyAction9(strm, yyNO_MATCH)
            else if inp < #"`"
              then if inp = #"["
                  then yyAction9(strm, yyNO_MATCH)
                else if inp < #"["
                  then yyQ22(strm', yyMATCH(strm, yyAction9, yyNO_MATCH))
                else if inp = #"_"
                  then yyQ22(strm', yyMATCH(strm, yyAction9, yyNO_MATCH))
                  else yyAction9(strm, yyNO_MATCH)
            else if inp <= #"z"
              then yyQ22(strm', yyMATCH(strm, yyAction9, yyNO_MATCH))
              else yyAction9(strm, yyNO_MATCH)
      (* end case *))
fun yyQ31 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction14(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"["
              then yyAction14(strm, yyNO_MATCH)
            else if inp < #"["
              then if inp = #"0"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp < #"0"
                  then if inp = #"'"
                      then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                      else yyAction14(strm, yyNO_MATCH)
                else if inp = #":"
                  then yyAction14(strm, yyNO_MATCH)
                else if inp < #":"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp <= #"@"
                  then yyAction14(strm, yyNO_MATCH)
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp = #"a"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"a"
              then if inp = #"_"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyAction14(strm, yyNO_MATCH)
            else if inp = #"n"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"n"
              then if inp = #"m"
                  then yyQ32(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp <= #"z"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
              else yyAction14(strm, yyNO_MATCH)
      (* end case *))
fun yyQ30 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction14(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"["
              then yyAction14(strm, yyNO_MATCH)
            else if inp < #"["
              then if inp = #"0"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp < #"0"
                  then if inp = #"'"
                      then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                      else yyAction14(strm, yyNO_MATCH)
                else if inp = #":"
                  then yyAction14(strm, yyNO_MATCH)
                else if inp < #":"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp <= #"@"
                  then yyAction14(strm, yyNO_MATCH)
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp = #"a"
              then yyQ31(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"a"
              then if inp = #"_"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyAction14(strm, yyNO_MATCH)
            else if inp <= #"z"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
              else yyAction14(strm, yyNO_MATCH)
      (* end case *))
fun yyQ29 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction14(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"["
              then yyAction14(strm, yyNO_MATCH)
            else if inp < #"["
              then if inp = #"0"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp < #"0"
                  then if inp = #"'"
                      then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                      else yyAction14(strm, yyNO_MATCH)
                else if inp = #":"
                  then yyAction14(strm, yyNO_MATCH)
                else if inp < #":"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp <= #"@"
                  then yyAction14(strm, yyNO_MATCH)
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp = #"a"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"a"
              then if inp = #"_"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyAction14(strm, yyNO_MATCH)
            else if inp = #"s"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"s"
              then if inp = #"r"
                  then yyQ30(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp <= #"z"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
              else yyAction14(strm, yyNO_MATCH)
      (* end case *))
fun yyQ37 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction10(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"A"
              then yyQ22(strm', yyMATCH(strm, yyAction10, yyNO_MATCH))
            else if inp < #"A"
              then if inp = #"("
                  then yyAction10(strm, yyNO_MATCH)
                else if inp < #"("
                  then if inp = #"'"
                      then yyQ22(strm', yyMATCH(strm, yyAction10, yyNO_MATCH))
                      else yyAction10(strm, yyNO_MATCH)
                else if inp = #"0"
                  then yyQ22(strm', yyMATCH(strm, yyAction10, yyNO_MATCH))
                else if inp < #"0"
                  then yyAction10(strm, yyNO_MATCH)
                else if inp <= #"9"
                  then yyQ22(strm', yyMATCH(strm, yyAction10, yyNO_MATCH))
                  else yyAction10(strm, yyNO_MATCH)
            else if inp = #"`"
              then yyAction10(strm, yyNO_MATCH)
            else if inp < #"`"
              then if inp = #"["
                  then yyAction10(strm, yyNO_MATCH)
                else if inp < #"["
                  then yyQ22(strm', yyMATCH(strm, yyAction10, yyNO_MATCH))
                else if inp = #"_"
                  then yyQ22(strm', yyMATCH(strm, yyAction10, yyNO_MATCH))
                  else yyAction10(strm, yyNO_MATCH)
            else if inp <= #"z"
              then yyQ22(strm', yyMATCH(strm, yyAction10, yyNO_MATCH))
              else yyAction10(strm, yyNO_MATCH)
      (* end case *))
fun yyQ36 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction14(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"["
              then yyAction14(strm, yyNO_MATCH)
            else if inp < #"["
              then if inp = #"0"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp < #"0"
                  then if inp = #"'"
                      then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                      else yyAction14(strm, yyNO_MATCH)
                else if inp = #":"
                  then yyAction14(strm, yyNO_MATCH)
                else if inp < #":"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp <= #"@"
                  then yyAction14(strm, yyNO_MATCH)
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp = #"a"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"a"
              then if inp = #"_"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyAction14(strm, yyNO_MATCH)
            else if inp = #"f"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"f"
              then if inp = #"e"
                  then yyQ37(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp <= #"z"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
              else yyAction14(strm, yyNO_MATCH)
      (* end case *))
fun yyQ35 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction14(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"["
              then yyAction14(strm, yyNO_MATCH)
            else if inp < #"["
              then if inp = #"0"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp < #"0"
                  then if inp = #"'"
                      then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                      else yyAction14(strm, yyNO_MATCH)
                else if inp = #":"
                  then yyAction14(strm, yyNO_MATCH)
                else if inp < #":"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp <= #"@"
                  then yyAction14(strm, yyNO_MATCH)
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp = #"a"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"a"
              then if inp = #"_"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyAction14(strm, yyNO_MATCH)
            else if inp = #"s"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"s"
              then if inp = #"r"
                  then yyQ36(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp <= #"z"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
              else yyAction14(strm, yyNO_MATCH)
      (* end case *))
fun yyQ34 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction14(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"["
              then yyAction14(strm, yyNO_MATCH)
            else if inp < #"["
              then if inp = #"0"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp < #"0"
                  then if inp = #"'"
                      then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                      else yyAction14(strm, yyNO_MATCH)
                else if inp = #":"
                  then yyAction14(strm, yyNO_MATCH)
                else if inp < #":"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp <= #"@"
                  then yyAction14(strm, yyNO_MATCH)
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp = #"a"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"a"
              then if inp = #"_"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyAction14(strm, yyNO_MATCH)
            else if inp = #"v"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"v"
              then if inp = #"u"
                  then yyQ35(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp <= #"z"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
              else yyAction14(strm, yyNO_MATCH)
      (* end case *))
fun yyQ33 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction14(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"["
              then yyAction14(strm, yyNO_MATCH)
            else if inp < #"["
              then if inp = #"0"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp < #"0"
                  then if inp = #"'"
                      then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                      else yyAction14(strm, yyNO_MATCH)
                else if inp = #":"
                  then yyAction14(strm, yyNO_MATCH)
                else if inp < #":"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp <= #"@"
                  then yyAction14(strm, yyNO_MATCH)
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp = #"a"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"a"
              then if inp = #"_"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyAction14(strm, yyNO_MATCH)
            else if inp = #"e"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"e"
              then if inp = #"d"
                  then yyQ34(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp <= #"z"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
              else yyAction14(strm, yyNO_MATCH)
      (* end case *))
fun yyQ28 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction14(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"["
              then yyAction14(strm, yyNO_MATCH)
            else if inp < #"["
              then if inp = #"0"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp < #"0"
                  then if inp = #"'"
                      then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                      else yyAction14(strm, yyNO_MATCH)
                else if inp = #":"
                  then yyAction14(strm, yyNO_MATCH)
                else if inp < #":"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp <= #"@"
                  then yyAction14(strm, yyNO_MATCH)
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp = #"a"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"a"
              then if inp = #"_"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyAction14(strm, yyNO_MATCH)
            else if inp = #"f"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"f"
              then if inp = #"e"
                  then yyQ33(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp <= #"z"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
              else yyAction14(strm, yyNO_MATCH)
      (* end case *))
fun yyQ27 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction14(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"_"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"_"
              then if inp = #"0"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp < #"0"
                  then if inp = #"'"
                      then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                      else yyAction14(strm, yyNO_MATCH)
                else if inp = #"A"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp < #"A"
                  then if inp <= #"9"
                      then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                      else yyAction14(strm, yyNO_MATCH)
                else if inp <= #"Z"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyAction14(strm, yyNO_MATCH)
            else if inp = #"d"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"d"
              then if inp = #"a"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp < #"a"
                  then yyAction14(strm, yyNO_MATCH)
                else if inp = #"c"
                  then yyQ28(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp = #"h"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"h"
              then if inp = #"g"
                  then yyQ29(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp <= #"z"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
              else yyAction14(strm, yyNO_MATCH)
      (* end case *))
fun yyQ26 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction14(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"["
              then yyAction14(strm, yyNO_MATCH)
            else if inp < #"["
              then if inp = #"0"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp < #"0"
                  then if inp = #"'"
                      then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                      else yyAction14(strm, yyNO_MATCH)
                else if inp = #":"
                  then yyAction14(strm, yyNO_MATCH)
                else if inp < #":"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp <= #"@"
                  then yyAction14(strm, yyNO_MATCH)
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp = #"a"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"a"
              then if inp = #"_"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyAction14(strm, yyNO_MATCH)
            else if inp = #"p"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"p"
              then if inp = #"o"
                  then yyQ27(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp <= #"z"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
              else yyAction14(strm, yyNO_MATCH)
      (* end case *))
fun yyQ41 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction13(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"A"
              then yyQ22(strm', yyMATCH(strm, yyAction13, yyNO_MATCH))
            else if inp < #"A"
              then if inp = #"("
                  then yyAction13(strm, yyNO_MATCH)
                else if inp < #"("
                  then if inp = #"'"
                      then yyQ22(strm', yyMATCH(strm, yyAction13, yyNO_MATCH))
                      else yyAction13(strm, yyNO_MATCH)
                else if inp = #"0"
                  then yyQ22(strm', yyMATCH(strm, yyAction13, yyNO_MATCH))
                else if inp < #"0"
                  then yyAction13(strm, yyNO_MATCH)
                else if inp <= #"9"
                  then yyQ22(strm', yyMATCH(strm, yyAction13, yyNO_MATCH))
                  else yyAction13(strm, yyNO_MATCH)
            else if inp = #"`"
              then yyAction13(strm, yyNO_MATCH)
            else if inp < #"`"
              then if inp = #"["
                  then yyAction13(strm, yyNO_MATCH)
                else if inp < #"["
                  then yyQ22(strm', yyMATCH(strm, yyAction13, yyNO_MATCH))
                else if inp = #"_"
                  then yyQ22(strm', yyMATCH(strm, yyAction13, yyNO_MATCH))
                  else yyAction13(strm, yyNO_MATCH)
            else if inp <= #"z"
              then yyQ22(strm', yyMATCH(strm, yyAction13, yyNO_MATCH))
              else yyAction13(strm, yyNO_MATCH)
      (* end case *))
fun yyQ40 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction14(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"["
              then yyAction14(strm, yyNO_MATCH)
            else if inp < #"["
              then if inp = #"0"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp < #"0"
                  then if inp = #"'"
                      then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                      else yyAction14(strm, yyNO_MATCH)
                else if inp = #":"
                  then yyAction14(strm, yyNO_MATCH)
                else if inp < #":"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp <= #"@"
                  then yyAction14(strm, yyNO_MATCH)
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp = #"a"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"a"
              then if inp = #"_"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyAction14(strm, yyNO_MATCH)
            else if inp = #"t"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"t"
              then if inp = #"s"
                  then yyQ41(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp <= #"z"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
              else yyAction14(strm, yyNO_MATCH)
      (* end case *))
fun yyQ39 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction14(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"["
              then yyAction14(strm, yyNO_MATCH)
            else if inp < #"["
              then if inp = #"0"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp < #"0"
                  then if inp = #"'"
                      then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                      else yyAction14(strm, yyNO_MATCH)
                else if inp = #":"
                  then yyAction14(strm, yyNO_MATCH)
                else if inp < #":"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp <= #"@"
                  then yyAction14(strm, yyNO_MATCH)
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp = #"a"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"a"
              then if inp = #"_"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyAction14(strm, yyNO_MATCH)
            else if inp = #"n"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"n"
              then if inp = #"m"
                  then yyQ40(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp <= #"z"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
              else yyAction14(strm, yyNO_MATCH)
      (* end case *))
fun yyQ38 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction14(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"["
              then yyAction14(strm, yyNO_MATCH)
            else if inp < #"["
              then if inp = #"0"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp < #"0"
                  then if inp = #"'"
                      then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                      else yyAction14(strm, yyNO_MATCH)
                else if inp = #":"
                  then yyAction14(strm, yyNO_MATCH)
                else if inp < #":"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp <= #"@"
                  then yyAction14(strm, yyNO_MATCH)
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp = #"a"
              then yyQ39(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"a"
              then if inp = #"_"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyAction14(strm, yyNO_MATCH)
            else if inp <= #"z"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
              else yyAction14(strm, yyNO_MATCH)
      (* end case *))
fun yyQ25 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction14(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"["
              then yyAction14(strm, yyNO_MATCH)
            else if inp < #"["
              then if inp = #"0"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp < #"0"
                  then if inp = #"'"
                      then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                      else yyAction14(strm, yyNO_MATCH)
                else if inp = #":"
                  then yyAction14(strm, yyNO_MATCH)
                else if inp < #":"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp <= #"@"
                  then yyAction14(strm, yyNO_MATCH)
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp = #"a"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"a"
              then if inp = #"_"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyAction14(strm, yyNO_MATCH)
            else if inp = #"s"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"s"
              then if inp = #"r"
                  then yyQ38(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp <= #"z"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
              else yyAction14(strm, yyNO_MATCH)
      (* end case *))
fun yyQ13 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction14(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"_"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"_"
              then if inp = #"0"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp < #"0"
                  then if inp = #"'"
                      then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                      else yyAction14(strm, yyNO_MATCH)
                else if inp = #"A"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp < #"A"
                  then if inp <= #"9"
                      then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                      else yyAction14(strm, yyNO_MATCH)
                else if inp <= #"Z"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyAction14(strm, yyNO_MATCH)
            else if inp = #"r"
              then yyQ26(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"r"
              then if inp = #"a"
                  then yyQ25(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp = #"`"
                  then yyAction14(strm, yyNO_MATCH)
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp <= #"z"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
              else yyAction14(strm, yyNO_MATCH)
      (* end case *))
fun yyQ46 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction11(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"A"
              then yyQ22(strm', yyMATCH(strm, yyAction11, yyNO_MATCH))
            else if inp < #"A"
              then if inp = #"("
                  then yyAction11(strm, yyNO_MATCH)
                else if inp < #"("
                  then if inp = #"'"
                      then yyQ22(strm', yyMATCH(strm, yyAction11, yyNO_MATCH))
                      else yyAction11(strm, yyNO_MATCH)
                else if inp = #"0"
                  then yyQ22(strm', yyMATCH(strm, yyAction11, yyNO_MATCH))
                else if inp < #"0"
                  then yyAction11(strm, yyNO_MATCH)
                else if inp <= #"9"
                  then yyQ22(strm', yyMATCH(strm, yyAction11, yyNO_MATCH))
                  else yyAction11(strm, yyNO_MATCH)
            else if inp = #"`"
              then yyAction11(strm, yyNO_MATCH)
            else if inp < #"`"
              then if inp = #"["
                  then yyAction11(strm, yyNO_MATCH)
                else if inp < #"["
                  then yyQ22(strm', yyMATCH(strm, yyAction11, yyNO_MATCH))
                else if inp = #"_"
                  then yyQ22(strm', yyMATCH(strm, yyAction11, yyNO_MATCH))
                  else yyAction11(strm, yyNO_MATCH)
            else if inp <= #"z"
              then yyQ22(strm', yyMATCH(strm, yyAction11, yyNO_MATCH))
              else yyAction11(strm, yyNO_MATCH)
      (* end case *))
fun yyQ45 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction14(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"["
              then yyAction14(strm, yyNO_MATCH)
            else if inp < #"["
              then if inp = #"0"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp < #"0"
                  then if inp = #"'"
                      then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                      else yyAction14(strm, yyNO_MATCH)
                else if inp = #":"
                  then yyAction14(strm, yyNO_MATCH)
                else if inp < #":"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp <= #"@"
                  then yyAction14(strm, yyNO_MATCH)
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp = #"a"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"a"
              then if inp = #"_"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyAction14(strm, yyNO_MATCH)
            else if inp = #"o"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"o"
              then if inp = #"n"
                  then yyQ46(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp <= #"z"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
              else yyAction14(strm, yyNO_MATCH)
      (* end case *))
fun yyQ44 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction14(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"["
              then yyAction14(strm, yyNO_MATCH)
            else if inp < #"["
              then if inp = #"0"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp < #"0"
                  then if inp = #"'"
                      then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                      else yyAction14(strm, yyNO_MATCH)
                else if inp = #":"
                  then yyAction14(strm, yyNO_MATCH)
                else if inp < #":"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp <= #"@"
                  then yyAction14(strm, yyNO_MATCH)
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp = #"a"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"a"
              then if inp = #"_"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyAction14(strm, yyNO_MATCH)
            else if inp = #"h"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"h"
              then if inp = #"g"
                  then yyQ45(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp <= #"z"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
              else yyAction14(strm, yyNO_MATCH)
      (* end case *))
fun yyQ43 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction14(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"["
              then yyAction14(strm, yyNO_MATCH)
            else if inp < #"["
              then if inp = #"0"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp < #"0"
                  then if inp = #"'"
                      then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                      else yyAction14(strm, yyNO_MATCH)
                else if inp = #":"
                  then yyAction14(strm, yyNO_MATCH)
                else if inp < #":"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp <= #"@"
                  then yyAction14(strm, yyNO_MATCH)
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp = #"a"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"a"
              then if inp = #"_"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyAction14(strm, yyNO_MATCH)
            else if inp = #"j"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"j"
              then if inp = #"i"
                  then yyQ44(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp <= #"z"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
              else yyAction14(strm, yyNO_MATCH)
      (* end case *))
fun yyQ42 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction14(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"["
              then yyAction14(strm, yyNO_MATCH)
            else if inp < #"["
              then if inp = #"0"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp < #"0"
                  then if inp = #"'"
                      then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                      else yyAction14(strm, yyNO_MATCH)
                else if inp = #":"
                  then yyAction14(strm, yyNO_MATCH)
                else if inp < #":"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp <= #"@"
                  then yyAction14(strm, yyNO_MATCH)
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp = #"a"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"a"
              then if inp = #"_"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyAction14(strm, yyNO_MATCH)
            else if inp = #"t"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"t"
              then if inp = #"s"
                  then yyQ43(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp <= #"z"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
              else yyAction14(strm, yyNO_MATCH)
      (* end case *))
fun yyQ12 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction14(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"["
              then yyAction14(strm, yyNO_MATCH)
            else if inp < #"["
              then if inp = #"0"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp < #"0"
                  then if inp = #"'"
                      then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                      else yyAction14(strm, yyNO_MATCH)
                else if inp = #":"
                  then yyAction14(strm, yyNO_MATCH)
                else if inp < #":"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp <= #"@"
                  then yyAction14(strm, yyNO_MATCH)
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp = #"a"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"a"
              then if inp = #"_"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyAction14(strm, yyNO_MATCH)
            else if inp = #"t"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"t"
              then if inp = #"s"
                  then yyQ42(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp <= #"z"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
              else yyAction14(strm, yyNO_MATCH)
      (* end case *))
fun yyQ11 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction14(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"A"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
            else if inp < #"A"
              then if inp = #"("
                  then yyAction14(strm, yyNO_MATCH)
                else if inp < #"("
                  then if inp = #"'"
                      then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                      else yyAction14(strm, yyNO_MATCH)
                else if inp = #"0"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp < #"0"
                  then yyAction14(strm, yyNO_MATCH)
                else if inp <= #"9"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyAction14(strm, yyNO_MATCH)
            else if inp = #"`"
              then yyAction14(strm, yyNO_MATCH)
            else if inp < #"`"
              then if inp = #"["
                  then yyAction14(strm, yyNO_MATCH)
                else if inp < #"["
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                else if inp = #"_"
                  then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
                  else yyAction14(strm, yyNO_MATCH)
            else if inp <= #"z"
              then yyQ22(strm', yyMATCH(strm, yyAction14, yyNO_MATCH))
              else yyAction14(strm, yyNO_MATCH)
      (* end case *))
fun yyQ10 (strm, lastMatch : yymatch) = yyAction7(strm, yyNO_MATCH)
fun yyQ47 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction2(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #";"
              then yyQ47(strm', yyMATCH(strm, yyAction2, yyNO_MATCH))
              else yyAction2(strm, yyNO_MATCH)
      (* end case *))
fun yyQ9 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction2(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #";"
              then yyQ47(strm', yyMATCH(strm, yyAction2, yyNO_MATCH))
              else yyAction2(strm, yyNO_MATCH)
      (* end case *))
fun yyQ8 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction16(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"/"
              then yyAction16(strm, yyNO_MATCH)
            else if inp < #"/"
              then if inp = #"."
                  then yyQ19(strm', yyMATCH(strm, yyAction16, yyNO_MATCH))
                  else yyAction16(strm, yyNO_MATCH)
            else if inp <= #"9"
              then yyQ18(strm', yyMATCH(strm, yyAction16, yyNO_MATCH))
              else yyAction16(strm, yyNO_MATCH)
      (* end case *))
fun yyQ7 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction16(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"."
              then yyQ19(strm', yyMATCH(strm, yyAction16, yyNO_MATCH))
              else yyAction16(strm, yyNO_MATCH)
      (* end case *))
fun yyQ6 (strm, lastMatch : yymatch) = yyAction8(strm, yyNO_MATCH)
fun yyQ5 (strm, lastMatch : yymatch) = yyAction4(strm, yyNO_MATCH)
fun yyQ4 (strm, lastMatch : yymatch) = yyAction3(strm, yyNO_MATCH)
fun yyQ3 (strm, lastMatch : yymatch) = yyAction1(strm, yyNO_MATCH)
fun yyQ48 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction0(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"\n"
              then yyAction0(strm, yyNO_MATCH)
            else if inp < #"\n"
              then if inp = #"\t"
                  then yyQ48(strm', yyMATCH(strm, yyAction0, yyNO_MATCH))
                  else yyAction0(strm, yyNO_MATCH)
            else if inp = #" "
              then yyQ48(strm', yyMATCH(strm, yyAction0, yyNO_MATCH))
              else yyAction0(strm, yyNO_MATCH)
      (* end case *))
fun yyQ2 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE => yyAction0(strm, yyNO_MATCH)
        | SOME(inp, strm') =>
            if inp = #"\n"
              then yyAction0(strm, yyNO_MATCH)
            else if inp < #"\n"
              then if inp = #"\t"
                  then yyQ48(strm', yyMATCH(strm, yyAction0, yyNO_MATCH))
                  else yyAction0(strm, yyNO_MATCH)
            else if inp = #" "
              then yyQ48(strm', yyMATCH(strm, yyAction0, yyNO_MATCH))
              else yyAction0(strm, yyNO_MATCH)
      (* end case *))
fun yyQ1 (strm, lastMatch : yymatch) = yyAction17(strm, yyNO_MATCH)
fun yyQ0 (strm, lastMatch : yymatch) = (case (yygetc(strm))
       of NONE =>
            if yyInput.eof(!(yystrm))
              then UserDeclarations.eof(yyarg)
              else yystuck(lastMatch)
        | SOME(inp, strm') =>
            if inp = #"<"
              then yyQ1(strm', lastMatch)
            else if inp < #"<"
              then if inp = #")"
                  then yyQ5(strm', lastMatch)
                else if inp < #")"
                  then if inp = #"\v"
                      then yyQ1(strm', lastMatch)
                    else if inp < #"\v"
                      then if inp = #"\t"
                          then yyQ2(strm', lastMatch)
                        else if inp = #"\n"
                          then yyQ3(strm', lastMatch)
                          else yyQ1(strm', lastMatch)
                    else if inp = #"!"
                      then yyQ1(strm', lastMatch)
                    else if inp < #"!"
                      then if inp = #" "
                          then yyQ2(strm', lastMatch)
                          else yyQ1(strm', lastMatch)
                    else if inp = #"("
                      then yyQ4(strm', lastMatch)
                      else yyQ1(strm', lastMatch)
                else if inp = #"0"
                  then yyQ7(strm', lastMatch)
                else if inp < #"0"
                  then if inp = #","
                      then yyQ6(strm', lastMatch)
                      else yyQ1(strm', lastMatch)
                else if inp = #":"
                  then yyQ1(strm', lastMatch)
                else if inp = #";"
                  then yyQ9(strm', lastMatch)
                  else yyQ8(strm', lastMatch)
            else if inp = #"q"
              then yyQ11(strm', lastMatch)
            else if inp < #"q"
              then if inp = #"["
                  then yyQ1(strm', lastMatch)
                else if inp < #"["
                  then if inp = #">"
                      then yyQ1(strm', lastMatch)
                    else if inp < #">"
                      then yyQ10(strm', lastMatch)
                    else if inp <= #"@"
                      then yyQ1(strm', lastMatch)
                      else yyQ11(strm', lastMatch)
                else if inp = #"b"
                  then yyQ11(strm', lastMatch)
                else if inp < #"b"
                  then if inp = #"a"
                      then yyQ12(strm', lastMatch)
                      else yyQ1(strm', lastMatch)
                else if inp = #"p"
                  then yyQ13(strm', lastMatch)
                  else yyQ11(strm', lastMatch)
            else if inp = #"|"
              then yyQ1(strm', lastMatch)
            else if inp < #"|"
              then if inp = #"w"
                  then yyQ11(strm', lastMatch)
                else if inp < #"w"
                  then if inp = #"v"
                      then yyQ14(strm', lastMatch)
                      else yyQ11(strm', lastMatch)
                else if inp = #"{"
                  then yyQ15(strm', lastMatch)
                  else yyQ11(strm', lastMatch)
            else if inp = #"~"
              then yyQ17(strm', lastMatch)
            else if inp = #"}"
              then yyQ16(strm', lastMatch)
              else yyQ1(strm', lastMatch)
      (* end case *))
in
  (case (!(yyss))
   of INITIAL => yyQ0(!(yystrm), yyNO_MATCH)
  (* end case *))
end
            end
	  in 
            continue() 	  
	    handle IO.Io{cause, ...} => raise cause
          end
        in 
          lex 
        end
    in
    fun makeLexer yyinputN = mk (yyInput.mkStream yyinputN)
    fun makeLexer' ins = mk (yyInput.mkStream ins)
    end

  end
